spannertools.withdraw_components_from_spanners_covered_by_components
====================================================================

.. autofunction:: abjad.tools.spannertools.withdraw_components_from_spanners_covered_by_components.withdraw_components_from_spanners_covered_by_components
